#include "scanner.h"



int
check_argument(size_t size, char *arg[], argument_t *argument)
{

	if ( check_numbers_argument(size) == -1 )
		return -1;


	init_argument(size, arg, argument);


	if ( check_ip(argument->ip_start) == -1 )
		return -1;


	if ( check_ip(argument->ip_end) == -1 )
		return -1;


	return 0;
}



int
check_ip(const char *ip)
{

	int nbr;
	char *copy = NULL;
	char *search = NULL;
	char *check = NULL;


	copy = strdup(ip);

	if ( copy == NULL ) {
		fprintf(stderr, "strdup ip failed\n");
		return -1;
	}


	search = strtok(copy, ".");

	while ( search != NULL ) {

		if ( strlen(search) > 3 ) {
			fprintf(stderr, "len ip error\n");
			free(copy);
			return -1;
		}

		nbr = strtol(search, &check, 10);

		if ( *check != '\0' ) {
			fprintf(stderr, "value ip error\n");
			free(copy);
			return -1;
		}

		if ( nbr > 255 ) {
			fprintf(stderr, "ip > 255 , error\n");
			free(copy);
			return -1;
		}

		search = strtok(NULL, ".");

	}
	
	free(copy);
	return 0;
}





void
init_argument(size_t size, char *arg[], argument_t *argument)
{

	int i = 0;
	argument->timeout = 3;
	argument->log = 0;
	argument->verbose = 0;
	argument->nbr_thread = 50;

	while ( i < size ) {

		if ( !strcmp(arg[i], "-b") )   strcpy(argument->ip_start, arg[i+1]);
		else if ( !strcmp(arg[i], "-e") )   strcpy(argument->ip_end, arg[i+1]);
		else if ( !strcmp(arg[i], "-t") )   argument->timeout = atoi(arg[i+1]);
		else if ( !strcmp(arg[i], "-l") )   argument->log = 1;
		else if ( !strcmp(arg[i], "-v") )   argument->verbose = 1;
		else if ( !strcmp(arg[i], "-thread") )   argument->nbr_thread = atoi(arg[i+1]);

		i++;

	}
}



int
check_numbers_argument(size_t size)
{

	if ( size < 5 || size > 11 ) {
		fprintf(stderr, "!! numbers argument error\n");
		return -1;
	}

	return 0;
}



void
argument_free(argument_t *argument)
{

	if ( argument != NULL ) {

		free(argument);
		argument = NULL;

	}
}

